%%% MAKES A COB WEB PLOT FOR A LOGISTIC MAP

%%% Vivaldo M. Mendes, ISCTE - Lisbon University Institute, January 2009

%%% Includes the iteration process (Fig 1) and the associated time series(Fig 2)
clear;
clc;

%%%% STEP 1: PLOT THE MAP FUNCTION AND THE LINE y=x
 fplot('3.88*y*(1-y)',[0 1]); hold on;
 axis([0 1 0 1]);
 set(gca,'XTick',(0:0.1:1),'YTick',(0:0.1:1))
 grid off;
 fplot('1*y',[0 1],'b');
 xlabel('$x(t)$','fontsize',14,'interpreter','latex'); 
 ylabel('$x(t+1)$','fontsize',14,'interpreter','latex');

 
%%%%%% STEP 2: COMPUTE TRAJECTORY 
a=3.88;          
x0=0.2          % Initial condition 
N=60;           % Number of iterations
x(1) = x0;    
for ic=1:N
 x(ic+1) = a*x(ic)*(1-x(ic)); 
end

%%%%%% STEP 3: PLOT COBWEB
 line([x(1) x(1)],[0 x(2)],'Color','r') 
  plot(x(1), x(1),'ko');
 for ic=1:N-1
  line([x(ic) x(ic+1)],[x(ic+1) x(ic+1)],'Color','r')  
  line([x(ic+1) x(ic+1)],[x(ic+1) x(ic+2)],'Color','r')
  plot(x(ic+1), x(ic+1),'ko');
 end
 line([x(N) x(N+1)],[x(N+1) x(N+1)],'Color','r') 
 
   %%%%%% STEP 4: SIGN THE PLOT
 ht=text(0.1,0.82,['a=3.88']); set(ht,'FontSize',12);
 figure
 plot(x,'-*')
 grid on
 xlabel('$t$','fontsize',14,'interpreter','latex'); 
 ylabel('$x(t)$','fontsize',14,'interpreter','latex');

