% Routine written by Andreas Muller, University of Essex
%
function [trend,cycle] = myhpfilter(y,lambda)
%% HP-filters the series y and returns its trend and cycle components
% let:
% - N be the total number of variables
% - T be the number of time observations
% y is the data matrix with dimensions [TxN]
% lambda is the smoothing parameter

% get dimension of the data, y
[T,N] = size(y);

% assertions:
if T<3
    error('Error: T<3 detected, not enough data points to run the filter.');
elseif sum(sum(isnan(y)))>0
    error('Error: NaN''s in the data matrix detected.');
elseif T<N
    display('Warning: T<N detected, please make sure data matrix is provided in the format [TxN].');
end

% setup the main diagonal elements of the matrix A
d = repmat([1,-4,6,-4,1],T,1);

% set up matrix A, by filling up diagonal elements
A = diag(d(1:end-2,1),-2)+diag(d(1:end-1,2),-1)+diag(d(:,3),0)+diag(d(1:end-1,4),1)+diag(d(1:end-2,5),2);

% manually correct the irregular entries in the first two and the last two
% rows
A(1,1) = 1;
A(1,2) = -2;
A(2,1) = -2;
A(2,2) = 5;

A(end,end) = 1;
A(end,end-1) = -2;
A(end-1,end) = -2;
A(end-1,end-1) = 5;

% the backslash divide "\" is faster than taking the inverse
trend = (lambda*A+diag(ones(T,1),0))\y;
cycle = y-trend;

end