% SIMULATES AN AR(1)PROCESS with an IRF
% VIvaldo M. Mendes, ISCTE - Lisbon University Institute, January 2009
% Uses the well know Vivaldo's stupid equation  x(i+1)=a+b*x(i)+e(i+1)

clear,clc

% Number of iterations
N=30

% Setting the shock
epsilon=zeros(1,N); % one vector with 1 line and 30 columns, all entries equal to zero 
epsilon(1,1)=15 % Only the first element of the vector epsilon will be different from zero (equal to 1)

x(1)=20;% Initial condition 
b=0; % Setting rho such that the loop can take place
time=0:30; %This allows us to have the dynamics starting at period zero in the figure
a=10;

% Loop for the iterations
for i=1:N
    x(i+1)=a+b*x(i)+epsilon(i);
end

figure
plot(time,x,'-*b');
title('Impulse response function: Vivaldo-stupid equation')
axis([0,15,10,40])% Setting the range of the x,y axis (0<x<30;-1.4<y<1.4)
text(10,11,'b=0')% the text 'rho=0' will be placed in a particular point in the axisx,y (x=2.2;y=0.08)
hold on
xlabel('$t$','fontsize',14,'interpreter','latex'); 
ylabel('$x(t)$','fontsize',14,'interpreter','latex');


% Using various other different values for parameter "rho"

b=0.5; 
for i=1:N
    x(i+1)=a+b*x(i)+epsilon(i);
end
hold on
plot(time,x,'-or');
text(10,19,'b=0.5')

b=0.6; 
for i=1:N
    x(i+1)=a+b*x(i)+epsilon(i);
end
hold on
plot(time,x,'-*k')
text(10,26,'b=0.6')

hold off
grid on


    
    