
%Calculates the coefficients of autocorrelation and crosscorrelation
%Vivaldo M. Mendes, ISCTE-Lisbon University Institute, January 2009

%Requires hpfilter.m
%Requires USdata.txt


%Load tyhe data file
load USdata.txt;
time=1947:0.25:2008.50;
GDP=USdata(:,7);
INV=USdata(:,8);
CONS=USdata(:,10);


%Defining the variables which we are going to work with (hpGDP,hpCONS,hpINV) and (x,y,w)

hpGDP = hpfilter(GDP,1600,[]);
hpCONS = hpfilter(CONS,1600,[]);
hpINV = hpfilter(INV,1600,[]);

y_gap=GDP-hpGDP;
c_gap=CONS-hpCONS;
i_gap=INV-hpINV;

% Making a figure to see if everything looks  OK
figure;
plot(time',y_gap,'-b'); grid on
title('GDP')
figure;
plot(time,c_gap,'-r'); grid on
title('Consumption')
figure;
plot(time,i_gap,'k'); grid on
title('Investment')

% Making a scatter plot of Consumption and Investment agaisnt GDP
figure
scatter(y_gap,c_gap,'*b');
xlabel('Consumption');
ylabel('GDP')
title('GDP vs Consumption');

figure
scatter(y_gap,i_gap,'*r');
xlabel('Investment');
ylabel('GDP')
title('GDP vs Investment');

figure
scatter(y_gap,y_gap,'*b');
xlabel('GDP');
ylabel('GDP')
title('GDP vs GDP');



%Now calculate the sample autocorrelation function for the 3 variables
    lag=0:10;
    figure
    subplot(131);plot(lag,autocorr(y_gap,10),'o-b'),
    grid on; title('GDP')
    subplot(132);plot(lag,autocorr(c_gap,10),'*-r'),
    grid on; title('C')
    subplot(133);plot(lag,autocorr(i_gap,10),'+-k'),
    grid on; title('I')
    
    
   
    
%Now calculate the crosscorrelation between each relevant variable and Output Gap
    
    lags=-20:20;
    
     figure
    title('Cross correlation')
    subplot(131);plot(lags,crosscorr(y_gap,y_gap,20),'o-b'),
    grid on; title('GDP')
    
    subplot(132);plot(lags,crosscorr(y_gap,c_gap,20),'*-r'),
    grid on; title('C')
    
    subplot(133);plot(lags,crosscorr(y_gap,i_gap,20),'+-k'),
    grid on; title('I')
    
      
    
    
    %Now, let's finish with calculating the Standard DEviation of each
    %variable.
    sigma_y=std(y_gap)
    sigma_c=std(c_gap)
    sigma_i=std(i_gap)
    
       
    figure
    y_y=[sigma_y sigma_c sigma_i];
    names={'Output gap';'Consumption';'Investment'}
    bar(y_y)
    set(gca,'xticklabel',names)
    title('Standard Deviation')
    grid on
   
    



