% Calculates the Hodrick-Prescott filter (the trend) and the short term business cycle component
% Vivaldo M. Mendes, ISCTE-Lisbon University Institute, January 2009

% Requires: hpfilter.m 
% Requires: penta2.m
% lambda= Smoothing parameter (monthly: 14400, quarterly: 1600, year: 100)
% requires a time series (in this case, the data is "USdata.txt")

clear;clc;

% load data and fix the range and frequency of the time series
load USdata.txt;
time=1947:0.25:2008.50;
GDP=USdata(:,7);
INV=USdata(:,8);
CONS=USdata(:,10);

% make separate figures: hp trend against the original data, and the short term cyclical component
% for colum 7 of the USdata.txt
figure
hp_GDP = hpfilter(GDP,1600);
plot(time',hp_GDP,'r'); hold on; 
plot(time',GDP);
gap_GDP=GDP-hp_GDP;
grid on;
xlabel('time (quarters)');
ylabel('GDP')
title('GDP and its trend (HP filtered)');

figure;
plot(time',gap_GDP)
grid on;
xlabel('time (quarters)');
ylabel('Output gap')
title('Output gap (HP filtered)');


% repeats the previous steps, but now for column 10 of USdata.txt
figure
hp_INV = hpfilter(INV,1600);
plot(time',hp_INV,'r'); hold on; 
plot(time',INV);
gap_INV=INV-hp_INV;
xlabel('time (quarters)');
ylabel('Investment')
title('Investment and its trend (HP filtered)');

figure;
plot(time',gap_INV)
grid on;
xlabel('time (quarters)');
ylabel('Investment gap')
title('Investment gap (HP filtered)');