% SIMULATES AN AR(1)PROCESS with an IRF
% VIvaldo M. Mendes, ISCTE - Lisbon University Institute, January 2009

clear,clc

% Number of iterations
N=30

% Setting the shock
epsilon=zeros(1,N); % one vector with 1 line and 30 columns, all entries equal to zero 
epsilon(1,1)=1 % Only the firts element of the vector epsilon will be different from zero (equal to 1)

v(1)=0;% Initial condition 
rho=0; % Setting rho such that the loop can take place
time=0:29;

% Loop for the iterations
for i=1:N
    v(i+1)=rho*v(i)+epsilon(i);
end

figure
plot(v,'-*b');
title('Impulse response AR(1)')
axis([0,30,-0.10,1.4])% Setting the range of the x,y axis (0<x<30;-1.4<y<1.4)
text(2.2,0.08,'rho=0')% the text 'rho=0' will be placed in a particular point in the axisx,y (x=2.2;y=0.08)
hold on
xlabel('$t$','fontsize',14,'interpreter','latex'); 
ylabel('$x(t)$','fontsize',14,'interpreter','latex');


% Using various other different values for parameter "rho"

rho=0.5; 
for i=1:N
    v(i+1)=rho*v(i)+epsilon(i);
end
hold on
plot(v,'-or');
text(5,0.2,'rho=0.5')

rho=0.9; 
for i=1:N
    v(i+1)=rho*v(i)+epsilon(i);
end
hold on
plot(v,'-*c')
text(16,0.3,'rho=0.9')

rho=0.99; 
for i=1:N
    v(i+1)=rho*v(i)+epsilon(i);
end
hold on
plot(v,'-ob')
text(22,0.85,'rho=0.99')
 
 rho=1.0; 
for i=1:N
    v(i+1)=rho*v(i)+epsilon(i);
end
hold on
plot(v,'-og')
text(25,1.05,'rho=1')

 rho=1.01; 
for i=1:N
    v(i+1)=rho*v(i)+epsilon(i);
end
hold on
plot(v,'-*r')
text(20,1.3,'rho=1.01')

hold off
grid on


    